@@ -1,14 +1,11 @@
 """contact message API
 """
 import logging
-
+from django.conf import settings
+import core_main_app.utils.notifications.mail as send_mail_api
 from core_main_app.commons import exceptions
 from core_website_app.components.contact_message.models import ContactMessage
-import core_main_app.utils.notifications.mail as send_mail_api
-from core_website_app.settings import (
-    SERVER_URI,
-    SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED,
-)
+from core_website_app.settings import SERVER_URI
 
 
 logger = logging.getLogger("core_website_app.components.contact_message.api")
@@ -43,9 +40,11 @@ def get(message_id):
     """
     try:
         return ContactMessage.get_by_id(message_id)
-    except Exception as e:
-        logger.error(str(e))
-        raise exceptions.ApiError("No message could be found with the given id.")
+    except Exception as exception:
+        logger.error(str(exception))
+        raise exceptions.ApiError(
+            "No message could be found with the given id."
+        )
 
 
 def upsert(contact_message):
@@ -60,10 +59,11 @@ def upsert(contact_message):
     try:
         # Check if new contact message
         if contact_message.id is None:
-            if SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED:
+            if settings.SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED:
                 context = {"URI": SERVER_URI}
                 template_path = (
-                    "core_website_app/admin/email/contact_message_for_admin.html"
+                    "core_website_app/admin/email"
+                    "/contact_message_for_admin.html"
                 )
 
                 send_mail_api.send_mail_to_administrators(
@@ -74,8 +74,8 @@ def upsert(contact_message):
 
         # save method return self
         return contact_message.save()
-    except Exception as e:
-        logger.error(str(e))
+    except Exception as exception:
+        logger.error(str(exception))
         raise exceptions.ApiError("Save message failed")
 
 
@@ -90,6 +90,6 @@ def delete(contact_message):
     """
     try:
         contact_message.delete()
-    except Exception as e:
-        logger.error(str(e))
+    except Exception as exception:
+        logger.error(str(exception))
         raise exceptions.ApiError("Impossible to delete contact message.")
