@@ -1,3 +1,6 @@
+""" Menus
+"""
+
 from django.urls import reverse
 from menu import Menu, MenuItem
 
@@ -12,18 +15,25 @@ from core_website_app.settings import (
 if DISPLAY_PRIVACY_POLICY_FOOTER:
     Menu.add_item(
         "footer",
-        MenuItem("Privacy policy", reverse("core_website_app_privacy"), weight=1001),
+        MenuItem(
+            "Privacy policy", reverse("core_website_app_privacy"), weight=1001
+        ),
     )
 if DISPLAY_TERMS_OF_USE_FOOTER:
     Menu.add_item(
         "footer",
-        MenuItem("Terms of use", reverse("core_website_app_terms"), weight=1002),
+        MenuItem(
+            "Terms of use", reverse("core_website_app_terms"), weight=1002
+        ),
     )
 if DISPLAY_CONTACT_FOOTER:
     Menu.add_item(
         "footer",
         MenuItem(
-            "Contact", reverse("core_website_app_contact"), icon="envelope", weight=1003
+            "Contact",
+            reverse("core_website_app_contact"),
+            icon="envelope",
+            weight=1003,
         ),
     )
 if DISPLAY_HELP_FOOTER:
@@ -50,31 +60,40 @@ if DISPLAY_RULES_OF_BEHAVIOR_FOOTER:
 # Admin menus for website app
 website_children = (
     MenuItem(
-        "Privacy Policy", reverse("admin:core_website_app_privacy"), icon="user-secret"
+        "Privacy Policy",
+        reverse("core-admin:core_website_app_privacy"),
+        icon="user-secret",
     ),
-    MenuItem("Terms of Use", reverse("admin:core_website_app_terms"), icon="file-alt"),
     MenuItem(
-        "Help Page", reverse("admin:core_website_app_help"), icon="question-circle"
+        "Terms of Use",
+        reverse("core-admin:core_website_app_terms"),
+        icon="file-alt",
+    ),
+    MenuItem(
+        "Help Page",
+        reverse("core-admin:core_website_app_help"),
+        icon="question-circle",
     ),
     MenuItem(
         "Rules of Behavior",
-        reverse("admin:core_website_app_rules_of_behavior"),
+        reverse("core-admin:core_website_app_rules_of_behavior"),
         icon="balance-scale",
     ),
     MenuItem(
         "User requests",
-        reverse("admin:core_website_app_user_requests"),
+        reverse("core-admin:core_website_app_user_requests"),
         icon="user-plus",
-        item_count_url="admin:core_website_app_request_count",
+        item_count_url="core-admin:core_website_app_request_count",
     ),
     MenuItem(
         "Contact messages",
-        reverse("admin:core_website_app_contact_messages"),
+        reverse("core-admin:core_website_app_contact_messages"),
         icon="envelope",
-        item_count_url="admin:core_website_app_message_count",
+        item_count_url="core-admin:core_website_app_message_count",
     ),
 )
 
 Menu.add_item(
-    "admin", MenuItem("WEBSITE", None, children=website_children, weight=-10000)
+    "admin",
+    MenuItem("WEBSITE", None, children=website_children, weight=-10000),
 )
