@@ -2,10 +2,10 @@
 """
 
 from django.test import SimpleTestCase
-from mock.mock import patch
+from unittest.mock import patch
 from rest_framework import status
 
-import core_website_app.rest.account_request.views as account_request_views
+
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
 from core_website_app.components.account_request.models import AccountRequest
@@ -13,10 +13,15 @@ from core_website_app.rest.account_request.serializers import (
     AccountRequestSerializer,
     UserSerializer,
 )
+import core_website_app.rest.account_request.views as account_request_views
 
 
 class TestAccountRequestListGetPermission(SimpleTestCase):
+    """Test Account Request List Get Permission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_anonymous=True),
@@ -25,6 +30,8 @@ class TestAccountRequestListGetPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_is_authenticated_returns_http_403(self):
+        """test_is_authenticated_returns_http_403"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_anonymous=False),
@@ -34,7 +41,11 @@ class TestAccountRequestListGetPermission(SimpleTestCase):
 
     @patch.object(AccountRequest, "get_all")
     @patch.object(AccountRequestSerializer, "data")
-    def test_is_staff_returns_http_200(self, account_serializer_data, account_get_all):
+    def test_is_staff_returns_http_200(
+        self, account_serializer_data, account_get_all
+    ):
+        """test_is_staff_returns_http_200"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_staff=True),
@@ -44,7 +55,11 @@ class TestAccountRequestListGetPermission(SimpleTestCase):
 
 
 class TestAccountRequestListPostPermission(SimpleTestCase):
+    """Test Account Request List Post Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.mock_data = {
             "username": "username",
             "first_name": "first_name",
@@ -58,6 +73,8 @@ class TestAccountRequestListPostPermission(SimpleTestCase):
     def test_anonymous_returns_http_201(
         self, user_serializer_save, user_serializer_is_valid
     ):
+        """test_anonymous_returns_http_201"""
+
         response = RequestMock.do_request_post(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_anonymous=True),
@@ -71,6 +88,8 @@ class TestAccountRequestListPostPermission(SimpleTestCase):
     def test_is_authenticated_returns_http_201(
         self, user_serializer_save, user_serializer_is_valid
     ):
+        """test_is_authenticated_returns_http_201"""
+
         response = RequestMock.do_request_post(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_anonymous=False),
@@ -84,6 +103,8 @@ class TestAccountRequestListPostPermission(SimpleTestCase):
     def test_is_staff_returns_http_201(
         self, user_serializer_save, user_serializer_is_valid
     ):
+        """test_is_staff_returns_http_201"""
+
         response = RequestMock.do_request_post(
             account_request_views.AccountRequestList.as_view(),
             create_mock_user("1", is_staff=True),
@@ -94,10 +115,16 @@ class TestAccountRequestListPostPermission(SimpleTestCase):
 
 
 class TestAccountRequestDetailGetPermission(SimpleTestCase):
+    """Test Account Request Detail Get Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestDetail.as_view(),
             create_mock_user("1", is_anonymous=True),
@@ -106,6 +133,8 @@ class TestAccountRequestDetailGetPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_is_authenticated_returns_http_403(self):
+        """test_is_authenticated_returns_http_403"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestDetail.as_view(),
             create_mock_user("1", is_anonymous=False),
@@ -118,6 +147,8 @@ class TestAccountRequestDetailGetPermission(SimpleTestCase):
     def test_is_staff_returns_http_200(
         self, account_serializer_data, account_get_by_id
     ):
+        """test_is_staff_returns_http_200"""
+
         response = RequestMock.do_request_get(
             account_request_views.AccountRequestDetail.as_view(),
             create_mock_user("1", is_staff=True),
@@ -128,10 +159,16 @@ class TestAccountRequestDetailGetPermission(SimpleTestCase):
 
 
 class TestAccountRequestDenyGetPermission(SimpleTestCase):
+    """Test Account Request Deny Get Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestDeny.as_view(),
             create_mock_user("1", is_anonymous=True),
@@ -140,6 +177,8 @@ class TestAccountRequestDenyGetPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_is_authenticated_returns_http_403(self):
+        """test_is_authenticated_returns_http_403"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestDeny.as_view(),
             create_mock_user("1", is_anonymous=False),
@@ -150,6 +189,8 @@ class TestAccountRequestDenyGetPermission(SimpleTestCase):
     @patch.object(AccountRequest, "get_by_id")
     @patch("core_website_app.components.account_request.api.deny")
     def test_is_staff_returns_http_200(self, account_api, account_get_by_id):
+        """test_is_staff_returns_http_200"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestDeny.as_view(),
             create_mock_user("1", is_staff=True),
@@ -160,10 +201,16 @@ class TestAccountRequestDenyGetPermission(SimpleTestCase):
 
 
 class TestAccountRequestAcceptGetPermission(SimpleTestCase):
+    """Test Account Request Accept Get Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestAccept.as_view(),
             create_mock_user("1", is_anonymous=True),
@@ -172,6 +219,8 @@ class TestAccountRequestAcceptGetPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_is_authenticated_returns_http_403(self):
+        """test_is_authenticated_returns_http_403"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestAccept.as_view(),
             create_mock_user("1", is_anonymous=False),
@@ -182,6 +231,8 @@ class TestAccountRequestAcceptGetPermission(SimpleTestCase):
     @patch.object(AccountRequest, "get_by_id")
     @patch("core_website_app.components.account_request.api.accept")
     def test_is_staff_returns_http_200(self, account_api, account_get_by_id):
+        """test_is_staff_returns_http_200"""
+
         response = RequestMock.do_request_patch(
             account_request_views.AccountRequestAccept.as_view(),
             create_mock_user("1", is_staff=True),
